Creación de rangos de direcciones públicas

Puede crear un rango de direcciones público definiendo su tamaño y, opcionalmente, especificando una VPC con la que asociarlo en cualquier zona de disponibilidad dentro de la cuenta.BYOIP (IPv4) Beta Las direcciones se pueden asignar a partir de los grupos de IP gestionados por IBM o de un CIDR personalizado autorizado, si desea utilizar su propio rango de IP enrutable públicamente.

Si la VPC se elimina mientras está vinculada a un intervalo de direcciones públicas, el intervalo de direcciones sigue existiendo y puede vincularse posteriormente a una VPC diferente en cualquier zona de disponibilidad.

Puedes crear rangos de direcciones públicas con la consola, CLI, API y Terraform.

Antes de empezar

Asegúrate de revisar las consideraciones de planificación para los rangos de megafonía.

Creación de rangos de direcciones públicas en la consola

Para crear rangos de direcciones públicas en la consola IBM Cloud, siga estos pasos:

  1. Desde la consola IBM Cloud, seleccione el ícono Menú del menú de navegación y luego haga clic en el ícono VPC de infraestructura > Red > Rangos de direcciones públicas. Aparece la página Rangos de direcciones públicas para VPC.

  2. Pulse Crear para ir a la página de suministro.

  3. En la sección Ubicación, indica la región en la que deseas que se cree el rango de direcciones públicas.

  4. En la sección Detalles, complete la información siguiente:

    • Tamaño: Seleccione el tamaño (número de direcciones IP) del rango de direcciones. Puedes elegir entre 1, 2, 4, 8 o 16 IPs para incluir en el bloque.

      Después de crear un rango de direcciones públicas, no puedes cambiar su tamaño.

    • Nombre: (Opcional): Introduce un nombre para el rango de direcciones públicas, como por ejemplo my-public-address-range.

    • Grupo de recursos: Seleccione un grupo de recursos para el intervalo de direcciones públicas.

      Después de crear un ámbito de direcciones públicas, no se puede cambiar el grupo de recursos.

    • Etiquetas: (Opcional) Añade etiquetas para ayudarte a organizar y encontrar tus recursos. Siempre puedes añadir más etiquetas más adelante. Para obtener más información, consulta Cómo trabajar con etiquetas. BYOIP (IPv4) Beta

    • Fuente de la dirección pública: Selecciona una de las siguientes opciones:

      • IBM CIDR: Selecciona entre los conjuntos de direcciones IP gestionados por IBM. A continuación, selecciona el tamaño (número de direcciones IP) del rango de direcciones. Puedes elegir entre 1, 2, 4, 8 o 16 IPs para incluir en el bloque.

        Después de crear un rango de direcciones públicas, no puedes cambiar su tamaño.

      • CIDR personalizados autorizados: En la lista de CIDR autorizados, selecciona el CIDR personalizado autorizado del que deseas asignar direcciones. Los bloques CIDR disponibles se limitan a los rangos válidos y no asignados dentro del CIDR personalizado autorizado seleccionado.

        Al seleccionar un CIDR personalizado autorizado, se asignan direcciones de su propio rango de IP en lugar de los grupos gestionados p IBM. Si no hay ningún CIDR autorizado en el menú, puedes introducir direcciones IP de un CIDR autorizado. El nuevo CIDR ya está disponible para su selección.

        Para obtener más información, consulta Aprovisionamiento de un CIDR autorizado personalizado.

      En el caso de los CIDR autorizados por zona, solo están disponibles los CIDR asociados a la zona seleccionada.

  5. (Opcional) Si desea vincular su rango de direcciones públicas a una VPC existente, active el interruptor Bind. A continuación, seleccione la VPC y la zona de disponibilidad a la que desea vincularse.

    Puede vincular un intervalo de direcciones públicas a cualquier VPC de una zona de disponibilidad única que ya exista en su cuenta. También puede vincular el rango de direcciones a una VPC más adelante. Para obtener más información, consulte Vinculación de un intervalo de direcciones públicas.

  6. Pulse Crear. Se solicita el uso del rango de direcciones públicas.

En la página Rangos de direcciones públicas para VPC, su rango de direcciones aparece en la tabla. El estado del rango de direcciones públicas tarda unos minutos en cambiar de a Updating Stable. Cuando se encuentra en el estado Stable, el rango de direcciones está listo para su uso.

Creación de rangos de direcciones públicas desde la CLI

Para crear rangos de direcciones públicas desde la línea de comando, siga estos pasos:

  1. Configure el entorno de la CLI.

  2. Inicia sesión en tu entorno CLI. Después de especificar la contraseña, el sistema solicita qué cuenta y región desea utilizar:

    ibmcloud login --sso
    
  3. Ejecute el mandato siguiente:

    ibmcloud is public-address-range-create --ipv4-address-count IPV4_ADDRESS_COUNT [--name NAME] [--vpc VPC --zone ZONE] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

    BYOIP (IPv4) Beta

    ibmcloud is public-address-range-create (--ipv4-address-count IPV4_ADDRESS_COUNT | --cidr CIDR) [--name NAME] [--vpc VPC --zone ZONE] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

    Donde:

    --ipv4-address-count
    El número total de direcciones IPv4 públicas necesarias. Debe ser una potencia de 2.BYOIP (IPv4) Beta Incompatible con --cidr.

    BYOIP (IPv4) Beta --cidr : El rango de direcciones públicas IPv4 para este rango de direcciones públicas expresado en formato CIDR. Debe ser un bloque no asignado dentro de un CIDR personalizado autorizado en su cuenta. Se excluye mutuamente con « --ipv4-address-count ».

    --name
    Un nombre para el rango de direcciones públicas. Los nombres que empiezan por ibm- están reservados para recursos gestionados por el proveedor y no están permitidos.
    --vpc
    La VPC a la que se debe vincular este rango de direcciones públicas. Requiere « --zone ».
    --zone
    La zona en la que se encuentra este rango de direcciones públicas. Requiere « --vpc ».
    --resource-group-id
    ID del grupo de recursos. Se excluye mutuamente con « --resource-group-name ».
    --resource-group-name
    Nombre del grupo de recursos. Se excluye mutuamente con « --resource-group-id ».
    --output
    En cuanto al formato de salida, solo se admite JSON. Valores posibles: JSON.
    -q, --quiet
    Suprimir la salida detallada.

Ejemplos de mandato

Cree un rango de direcciones públicas llamado public-address-range-1 con un recuento de direcciones de 8:

ibmcloud is public-address-range-create --name public-address-range-1 --ipv4-address-count 8

Crea un rango de direcciones públicas denominado public-address-range-2 con un número de direcciones igual a 4 y un grupo de recursos denominado Default:

ibmcloud is public-address-range-create --name public-address-range-2 --ipv4-address-count 4 --resource-group-name Default

Cree un intervalo de direcciones públicas denominado public-address-range-3 con un recuento de direcciones de 8, vinculado a la VPC cli-test-vpc en la zona us-south-1 con el ID de grupo de recursos 72b27b5c-f4b0-48bb-b954-5becc7c1dcb3:

ibmcloud is public-address-range-create --name public-address-range-3 --ipv4-address-count 8 --vpc cli-test-vpc --zone us-south-1 --resource-group-id 72b27b5c-f4b0-48bb-b954-5becc7c1dcb3

BYOIP (IPv4) BetaCrear un rango de direcciones públicas a partir de un CIDR personalizado autorizado, vinculado a una VPC y a una zona:

ibmcloud is public-address-range-create --name public-address-range-3 --cidr 46.16.186.112/28 --vpc cli-test-vpc --zone us-south-2 --resource-group-name Default

Crear un rango de direcciones públicas sin asignar a partir de un CIDR personalizado autorizado:

ibmcloud is public-address-range-create --name public-address-range-4 --cidr 46.16.186.128/28 --resource-group-name Default

Creación de rangos de direcciones públicas con la API

Antes de empezar, configura tu entorno de API.

Seleccione una de las opciones que aparecen continuación:

  • Crear un rango de direcciones públicas a partir de las direcciones IP gestionadas p IBM, asociadas a una VPC:

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "ipv4_address_count": 8,
          "name": "my-public-address-range",
          "target": {
             "vpc": {
                "id": "r006-4727d842-f94f-4a2d-824a-9bc9b02c523b"
             },
             "zone": {
                "name": "us-south-1"
             }
          }
       }'
    
  • Crear un rango de direcciones públicas no asignadas a partir de las direcciones IP gestionadas p IBM:

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "ipv4_address_count": 8,
          "name": "my-public-address-range"
       }'
    

BYOIP (IPv4) Beta

  • Crear un rango de direcciones públicas a partir de un CIDR personalizado autorizado (requiere una acción de IAM is.public-address-range.authorized-cidr.operate sobre el CIDR autorizado):

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "cidr": "192.168.3.192/28",
          "name": "my-par-from-cidr"
       }'
    

Si necesita cambiar el tamaño del ámbito de direcciones o del grupo de recursos, debe eliminar y volver a crear el ámbito de direcciones.

Próximos pasos